@@ -9,5 +9,5 @@ class DynamicGraphTutorialTest(unittest.TestCase):
         self.assertEqual(a.getCartMass(), 1)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
